"use strict";
// Copyright 2021 Twitter, Inc.
// SPDX-License-Identifier: Apache-2.0
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _OAuth2User_access_token, _OAuth2User_configuration, _OAuth2User_code_verifier, _OAuth2User_code_challenge;
Object.defineProperty(exports, "__esModule", { value: true });
exports.OAuth2User = void 0;
const crypto_1 = __importDefault(require("crypto"));
const utils_1 = require("./utils");
const request_1 = require("./request");
function sha256(buffer) {
    return crypto_1.default.createHash("sha256").update(buffer).digest();
}
function base64URLEncode(str) {
    return str
        .toString("base64")
        .replace(/\+/g, "-")
        .replace(/\//g, "_")
        .replace(/=/g, "");
}
class OAuth2User {
    constructor(configuration) {
        _OAuth2User_access_token.set(this, void 0);
        _OAuth2User_configuration.set(this, void 0);
        _OAuth2User_code_verifier.set(this, void 0);
        _OAuth2User_code_challenge.set(this, void 0);
        __classPrivateFieldSet(this, _OAuth2User_configuration, configuration, "f");
    }
    async refreshAccessToken() {
        const refresh_token = this.refresh_token;
        const credentials = __classPrivateFieldGet(this, _OAuth2User_configuration, "f");
        const params = {
            grant_type: "refresh_token",
            refresh_token: refresh_token,
        };
        const data = await (0, request_1.rest)({
            endpoint: `/2/oauth2/token`,
            params: params,
            method: "POST",
            headers: {
                "Content-type": "application/x-www-form-urlencoded",
                Authorization: (0, utils_1.basicAuthHeader)(credentials.client_id, credentials.client_secret),
            },
        });
        this.updateToken(data);
    }
    updateToken(data) {
        this.refresh_token = data.refresh_token;
        __classPrivateFieldSet(this, _OAuth2User_access_token, data.access_token, "f");
        this.token_type = data.token_type;
        this.expires_at = new Date(Date.now() + data.expires_in * 1000);
        this.scope = data.scope;
    }
    isAccessTokenExpired() {
        const refresh_token = this.refresh_token;
        const expires_at = this.expires_at;
        return (!!refresh_token &&
            (!expires_at || expires_at <= new Date(Date.now() + 1000)));
    }
    async requestAccessToken(code) {
        const credentials = __classPrivateFieldGet(this, _OAuth2User_configuration, "f");
        const code_verifier = __classPrivateFieldGet(this, _OAuth2User_code_verifier, "f") || __classPrivateFieldGet(this, _OAuth2User_code_challenge, "f");
        const params = {
            code,
            grant_type: "authorization_code",
            code_verifier: code_verifier,
            client_id: credentials.client_id,
            redirect_uri: credentials.callback,
        };
        const data = await (0, request_1.rest)({
            endpoint: `/2/oauth2/token`,
            params: params,
            method: "POST",
            headers: {
                "Content-type": "application/x-www-form-urlencoded",
                Authorization: (0, utils_1.basicAuthHeader)(credentials.client_id, credentials.client_secret),
            },
        });
        this.updateToken(data);
    }
    async revokeAccessToken() {
        const credentials = __classPrivateFieldGet(this, _OAuth2User_configuration, "f");
        const access_token = __classPrivateFieldGet(this, _OAuth2User_access_token, "f");
        const refresh_token = this.refresh_token;
        const configuration = __classPrivateFieldGet(this, _OAuth2User_configuration, "f");
        if (!access_token || !refresh_token)
            throw new Error("No access_token or refresh_token found");
        const useAccessToken = !!__classPrivateFieldGet(this, _OAuth2User_access_token, "f");
        const params = {
            token_type_hint: useAccessToken ? "access_token" : "refresh_token",
            token: useAccessToken ? access_token : refresh_token,
            client_id: configuration.client_id,
        };
        return (0, request_1.rest)({
            endpoint: `/2/oauth2/revoke`,
            params: params,
            method: "POST",
            headers: {
                "Content-Type": "application/x-www-form-urlencoded",
                Authorization: (0, utils_1.basicAuthHeader)(credentials.client_id, credentials.client_secret),
            },
        });
    }
    generateAuthURL(options) {
        const credentials = __classPrivateFieldGet(this, _OAuth2User_configuration, "f");
        if (!("callback" in credentials))
            throw new Error("You need to provide a callback and scopes");
        if (options.code_challenge_method === "s256") {
            const code_verifier = base64URLEncode(crypto_1.default.randomBytes(32));
            __classPrivateFieldSet(this, _OAuth2User_code_verifier, code_verifier, "f");
            __classPrivateFieldSet(this, _OAuth2User_code_challenge, base64URLEncode(sha256(code_verifier)), "f");
        }
        else {
            __classPrivateFieldSet(this, _OAuth2User_code_challenge, options.code_challenge, "f");
        }
        const code_challenge = __classPrivateFieldGet(this, _OAuth2User_code_challenge, "f");
        const url = new URL("https://twitter.com/i/oauth2/authorize");
        url.search = (0, utils_1.buildQueryString)({
            ...options,
            client_id: credentials.client_id,
            scope: credentials.scopes.join(" "),
            response_type: "code",
            redirect_uri: credentials.callback,
            code_challenge_method: options.code_challenge_method || "plain",
            code_challenge,
        });
        return url.toString();
    }
    async getAuthHeader() {
        if (!__classPrivateFieldGet(this, _OAuth2User_access_token, "f"))
            throw new Error("You do not have an access token");
        if (this.isAccessTokenExpired())
            await this.refreshAccessToken();
        return {
            Authorization: `Bearer ${__classPrivateFieldGet(this, _OAuth2User_access_token, "f")}`,
        };
    }
}
exports.OAuth2User = OAuth2User;
_OAuth2User_access_token = new WeakMap(), _OAuth2User_configuration = new WeakMap(), _OAuth2User_code_verifier = new WeakMap(), _OAuth2User_code_challenge = new WeakMap();
